@@ -1,8 +1,8 @@
 /*
 **  OSSP fsl - Faking/Flexible Syslog Library
-**  Copyright (c) 2002-2003 Ralf S. Engelschall <rse@engelschall.com>
-**  Copyright (c) 2002-2003 The OSSP Project <http://www.ossp.org/>
-**  Copyright (c) 2002-2003 Cable & Wireless Deutschland <http://www.cw.com/de/>
+**  Copyright (c) 2002-2004 Ralf S. Engelschall <rse@engelschall.com>
+**  Copyright (c) 2002-2004 The OSSP Project <http://www.ossp.org/>
+**  Copyright (c) 2002-2004 Cable & Wireless Deutschland <http://www.cw.com/de/>
 **
 **  This file is part of OSSP fsl, a syslog(3) API faking library which
 **  can be found at http://www.ossp.org/pkg/lib/fsl/.
@@ -371,16 +371,39 @@ CUS:
     return rc;
 }
 
+/* alphabetically compare two filenames, use with qsort(3) */
+static int fnamecmp(const void *str1, const void *str2)
+{
+    const char *s1 = *(const char **)str1;
+    const char *s2 = *(const char **)str2;
+
+    if ((s1 != NULL) && (s2 != NULL))
+        return strcmp(s1, s2);
+
+    /* this must never happen but be prepared for the impossible */
+
+    if ((s1 != NULL) && (s2 == NULL))
+        return strcmp(s1, "");
+
+    if ((s1 == NULL) && (s2 != NULL))
+        return strcmp("", s2);
+
+    return strcmp("", "");
+}
+
 /* read all possible files "fsl.*" into buffer */
 static fsl_rc_t readallfiles(buf_t *buffer)
 {
     fsl_rc_t rc;
     DIR *dp = NULL;
     struct dirent *de;
-    char *filename = NULL;
     char *cfgdir;
     char *prefix;
-    int n;
+    char **filearr = NULL;
+    size_t filemem = 0;
+    int filecnt = 0;
+    int fileidx = 0;
+    int n = 0;
 
     if (buffer == NULL)
         CU(FSL_ERR_ARG);
@@ -395,27 +418,39 @@ static fsl_rc_t readallfiles(buf_t *buffer)
 
     rc = FSL_ERR_ARG;
     while ((de = readdir(dp)) != NULL) {
-        n = strlen(de->d_name);
-        if (   (n >= strlen(prefix))
+        if (   (strlen(de->d_name) >= strlen(prefix))
             && (strncmp(de->d_name, prefix, strlen(prefix)) == 0)) {
-            if ((filename = (char *)malloc(strlen(cfgdir) + 1 + n + 1)) == NULL)
+
+            /* prepare to insert a new file string, so make room for one more */
+            if ((filearr = (char **)realloc(filearr, filemem + sizeof(char *))) == NULL)
                 CU(FSL_ERR_MEM);
-            filename[0] = '\0';
-            strcat(filename, cfgdir);
-            strcat(filename, "/");
-            strcat(filename, de->d_name);
-            if (appendfiletobuffer(buffer, filename) == FSL_OK)
-                rc = FSL_OK;
-            free(filename);
-            filename = NULL;
+            else
+                filemem += sizeof(char *);
+
+            /* allocate for actual filename string from dirent and copy out */
+            n = strlen(cfgdir) + strlen("/") + strlen(de->d_name) + 1;
+            if ((filearr[filecnt] = (char *)malloc(n)) == NULL)
+                CU(FSL_ERR_MEM);
+            *filearr[filecnt] = '\0';
+            strcat(filearr[filecnt], cfgdir);
+            strcat(filearr[filecnt], "/");
+            strcat(filearr[filecnt], de->d_name);
+            filecnt++;
         }
     }
+    qsort((void *)filearr, (size_t)filecnt, sizeof(char *), fnamecmp);
+    for (fileidx = 0; fileidx < filecnt; fileidx++)
+        if (appendfiletobuffer(buffer, filearr[fileidx]) == FSL_OK)
+            rc = FSL_OK;
     CU(rc);
 CUS:
     if (dp != NULL)
         closedir(dp);
-    if (filename != NULL)
-        free(filename);
+    if (filearr != NULL) {
+        for (fileidx = 0; fileidx < filecnt; fileidx++)
+            free(filearr[fileidx]);
+        free(filearr);
+    }
     return rc;
 }
 
@@ -543,7 +578,7 @@ static fsl_rc_t processcfg(cfg_t *cfg, char *cpISF, int mode)
     fsldebug(L2_LEVEL_TRACE, "processcfg() ident/facility=\"%s\", mode=%s", cpISF, mode == 0 ? "map/ident" : "default");
 
     /*  find configuration root node and check if it is a sequence and has one or more directives below it */
-    if ((cfgrv = cfg_node_root(cfg, &cfgseq)) != CFG_OK) {
+    if ((cfgrv = cfg_node_root(cfg, NULL, &cfgseq)) != CFG_OK) {
         (void)cfg_error(cfg, cfgrv, &cp); fsldebug(L2_LEVEL_ERROR, "processcfg: cfg_node_root() failed with error %s (%d)", cp, cfgrv); CU(FSL_ERR_CUS); }
 
     /*  only dump once */
@@ -892,21 +927,6 @@ int setlogmask(int maskpri)
     return oldmask;
 }
 
-/* faked POSIX API function syslog(3) */
-void syslog(int priority, const char *message, ...)
-{
-    va_list args;
-
-    /* tracing */
-    fsldebug(L2_LEVEL_TRACE, "fsl in syslog(3); go ahead using vsyslog(3)");
-
-    /* wrap around vsyslog(3) */
-    va_start(args, message);
-    vsyslog(priority, message, args);
-    va_end(args);
-    return;
-}
-
 /* faked POSIX API function vsyslog(3) */
 #ifdef HAVE_VSYSLOG_USVALIST
 void vsyslog(int priority, const char *fmt, __va_list args)
@@ -969,3 +989,18 @@ void vsyslog(int priority, const char *fmt, va_list args)
     return;
 }
 
+/* faked POSIX API function syslog(3) */
+void syslog(int priority, const char *message, ...)
+{
+    va_list args;
+
+    /* tracing */
+    fsldebug(L2_LEVEL_TRACE, "fsl in syslog(3); go ahead using vsyslog(3)");
+
+    /* wrap around vsyslog(3) */
+    va_start(args, message);
+    vsyslog(priority, message, args);
+    va_end(args);
+    return;
+}
+
