@@ -1,8 +1,8 @@
 /*
 **  OSSP cfg - Configuration Parsing
-**  Copyright (c) 2002-2002 Ralf S. Engelschall <rse@engelschall.com>
-**  Copyright (c) 2002-2002 The OSSP Project (http://www.ossp.org/)
-**  Copyright (c) 2002-2002 Cable & Wireless Deutschland (http://www.cw.com/de/)
+**  Copyright (c) 2002-2003 Ralf S. Engelschall <rse@engelschall.com>
+**  Copyright (c) 2002-2003 The OSSP Project (http://www.ossp.org/)
+**  Copyright (c) 2002-2003 Cable & Wireless (http://www.cw.com/)
 **
 **  This file is part of OSSP cfg, a configuration parsing
 **  library which can be found at http://www.ossp.org/pkg/lib/cfg/.
@@ -96,7 +96,9 @@
 #include <stdarg.h>
 #include <string.h>
 #include <ctype.h>
+#include <math.h>
 
+#include "config.h"
 #include "cfg_fmt.h"
 
 /* types which are locally use */
@@ -162,7 +164,8 @@ typedef unsigned long      u_quad_int;
         cfg_fmt_cvt((arg), (ndigits), (decpt), (sign), 0, (buf))
 
 /* inlined modf(3) to avoid dependency to external libm on systems
-   (like Tru64, QNX, etc) where modf(3) is not part of libc. */
+   (like Tru64, QNX, etc) where modf(3) is not part of libc.
+   We use trnc to avoid conflicts with global definitions of trunc and truncate */
 static double
 cfg_fmt_modf(
     double arg,
@@ -170,10 +173,10 @@ cfg_fmt_modf(
 {
     double fraction;
     double integral;
-    long trunc;
+    long trnc;
 
-    trunc = (long)arg;
-    integral = (double)trunc;
+    trnc = (long)arg;
+    integral = (double)trnc;
     fraction = arg - integral;
     if (iptr != NULL)
         *iptr = integral;
@@ -1040,7 +1043,7 @@ cfg_fmt_format(
                     if (vbuff->format != NULL) {
                         vbuff->format(vbuff,
                                       &prefix_char, &pad_char, &s, &s_len,
-                                      num_buf, NUM_BUF_SIZE, extinfo, *fmt, &ap);
+                                      num_buf, NUM_BUF_SIZE, extinfo, *fmt, (va_list *)(void *)&ap);
                         if (s == NULL)
                             return -1;
                     }
@@ -1150,14 +1153,16 @@ char *cfg_fmt_vasprintf(const char *fmt, va_list ap)
     char *s;
     int rv;
 
-    apbak = ap;
+    va_copy(apbak, ap);
     if ((rv = cfg_fmt_vsprintf(NULL, -1, fmt, ap)) == -1)
         return NULL;
     if ((s = malloc(rv+1)) == NULL)
         return NULL;
-    ap = apbak;
-    if ((rv = cfg_fmt_vsprintf(s, rv+1, fmt, ap)) == -1)
+    va_copy(ap, apbak);
+    if ((rv = cfg_fmt_vsprintf(s, rv+1, fmt, ap)) == -1) {
+        free(s);
         return NULL;
+    }
     return s;
 }
 
