@@ -1,8 +1,8 @@
 /*
 **  OSSP l2 - Flexible Logging
-**  Copyright (c) 2001-2003 Cable & Wireless Deutschland GmbH
-**  Copyright (c) 2001-2003 The OSSP Project (http://www.ossp.org/)
-**  Copyright (c) 2001-2003 Ralf S. Engelschall <rse@engelschall.com>
+**  Copyright (c) 2001-2004 Cable & Wireless <http://www.cw.com/>
+**  Copyright (c) 2001-2004 The OSSP Project <http://www.ossp.org/>
+**  Copyright (c) 2001-2004 Ralf S. Engelschall <rse@engelschall.com>
 **
 **  This file is part of OSSP l2, a flexible logging library which
 **  can be found at http://www.ossp.org/pkg/lib/l2/.
@@ -89,7 +89,7 @@ int main(int argc, char *argv[])
            "  filter(regex=hecking, negate=0)"
            "  -> prefix(prefix=\"[%d-%m-%Y/%H:%M:%S] %L test[%P]: \", timezone=local)"
            "     -> buffer(size=800)"
-           "        -> file(path=l2_test.log, append=1, perm=0644) ;"
+           "        -> file(path=l2_test.log, trunc=0, perm=0644) ;"
 /*
            "  syslog(ident=L2-Test, facility=user, "
            "         remotehost=localhost, logpid=1, target=remote)"
@@ -124,7 +124,7 @@ int main(int argc, char *argv[])
     /* create file channel */
     if ((rv = l2_channel_create(&chFile, env, "file")) != L2_OK)
         die(env, rv, "failed to create file channel");
-    if ((rv = l2_channel_configure(chFile, "path=l2_test.log, append=%d,perm=%d", TRUE, 0644)) != L2_OK)
+    if ((rv = l2_channel_configure(chFile, "path=l2_test.log, trunc=%d,perm=%d", 0, 0644)) != L2_OK)
         die(env, rv, "failed to configure file channel");
     if ((rv = l2_channel_levels(chFile, L2_LEVEL_UPTO(L2_LEVEL_INFO), L2_LEVEL_NONE)) != L2_OK)
         die(env, rv, "failed to level of smtp channel");
@@ -170,6 +170,10 @@ int main(int argc, char *argv[])
     if ((rv = l2_channel_destroy(ch)) != L2_OK)
         die(env, rv, "failed to destroy channel tree");
 
+    /* destroy environment */
+    if ((rv = l2_env_destroy(env)) != L2_OK)
+        die(env, rv, "failed to destroy environment");
+
     return 0;
 }
 
